@@ -1,6 +1,7 @@
 package Mercury;
+our $VERSION = '0.010';
 # ABSTRACT: Main broker application class
-$Mercury::VERSION = '0.009';
+
 #pod =head1 SYNOPSIS
 #pod
 #pod     # Start the broker
@@ -59,6 +60,9 @@ sub startup {
     $r->websocket( '/push/*topic' )
       ->to( controller => 'PushPull', action => 'push' )
       ->name( 'push' );
+    $r->post( '/push/*topic' )
+      ->to( controller => 'PushPull', action => 'post' )
+      ->name( 'push_post' );
     $r->websocket( '/pull/*topic' )
       ->to( controller => 'PushPull', action => 'pull' )
       ->name( 'pull' );
@@ -66,6 +70,9 @@ sub startup {
     $r->websocket( '/pub/*topic' )
       ->to( controller => 'PubSub::Cascade', action => 'publish' )
       ->name( 'pub' );
+    $r->post( '/pub/*topic' )
+      ->to( controller => 'PubSub::Cascade', action => 'post' )
+      ->name( 'pub_post' );
     $r->websocket( '/sub/*topic' )
       ->to( controller => 'PubSub::Cascade', action => 'subscribe' )
       ->name( 'sub' );
@@ -73,6 +80,9 @@ sub startup {
     $r->websocket( '/bus/*topic' )
       ->to( controller => 'Bus', action => 'connect' )
       ->name( 'bus' );
+    $r->post( '/bus/*topic' )
+      ->to( controller => 'Bus', action => 'post' )
+      ->name( 'bus_post' );
 
     if ( $app->mode eq 'development' ) {
         # Enable the example app
@@ -95,7 +105,7 @@ Mercury - Main broker application class
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -124,7 +134,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
