@@ -1,5 +1,5 @@
 package Mercury::Controller::PushPull;
-$Mercury::Controller::PushPull::VERSION = '0.009';
+our $VERSION = '0.010';
 # ABSTRACT: Push/pull message pattern controller
 
 #pod =head1 SYNOPSIS
@@ -74,6 +74,25 @@ sub pull {
     $c->rendered( 101 );
 }
 
+#pod =method post
+#pod
+#pod Post a new message to the given topic without subscribing or
+#pod establishing a WebSocket connection. This allows new messages to be
+#pod easily pushed by any HTTP client.
+#pod
+#pod =cut
+
+sub post {
+    my ( $c ) = @_;
+    my $topic = $c->stash( 'topic' );
+    my $pattern = $c->_pattern( $topic );
+    $pattern->send_message( $c->req->body );
+    $c->render(
+        status => 200,
+        text => '',
+    );
+}
+
 #=method _pattern
 #
 #   my $pattern = $c->_pattern( $topic );
@@ -105,7 +124,7 @@ Mercury::Controller::PushPull - Push/pull message pattern controller
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -148,6 +167,12 @@ One message from a pusher will be received by exactly one puller.
 
 This endpoint requires a C<topic> in the stash.
 
+=head2 post
+
+Post a new message to the given topic without subscribing or
+establishing a WebSocket connection. This allows new messages to be
+easily pushed by any HTTP client.
+
 =head1 SEE ALSO
 
 =over
@@ -164,7 +189,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
